package com.jprofiler.api.agent.mbean;

import com.jprofiler.agent.ControllerImpl;
import com.jprofiler.api.agent.HeapDumpOptions;

import java.io.File;

/**
 * This is JProfiler's MBean implementation. For direct calls from your code in
 * the same JVM, rather use the {@link com.jprofiler.api.agent.Controller} class.
 * 
 */
public class RemoteController implements RemoteControllerMBean {

    /** {@inheritDoc} */
    public void startCPURecording(boolean reset) {
        ControllerImpl.startCPURecording(reset);
    }

    /** {@inheritDoc} */
    public void stopCPURecording() {
        ControllerImpl.stopCPURecording();
    }

    /** {@inheritDoc} */
    public void startAllocRecording(boolean reset) {
        ControllerImpl.startAllocRecording(reset);
    }

    /** {@inheritDoc} */
    public void stopAllocRecording() {
        ControllerImpl.stopAllocRecording();
    }

    /** {@inheritDoc} */
    public void addBookmark(String description) {
        ControllerImpl.addBookmark(description);
    }

    /** {@inheritDoc} */
    public void triggerHeapDumpWithOptions(boolean fullGc, boolean selectRecorded, boolean primitiveData, boolean calculateRetainedSizes) {
        ControllerImpl.triggerHeapDump(new HeapDumpOptions().fullGc(fullGc).selectRecorded(selectRecorded).primitiveData(primitiveData).calculateRetainedSizes(calculateRetainedSizes));
    }

    /** {@inheritDoc} */
    public void triggerHeapDump() {
        triggerHeapDumpWithOptions(true, false, true, true);
    }

    /** {@inheritDoc} */
    public void saveSnapshot(String file) {
        ControllerImpl.saveSnapshot(new File(file), false);
    }

    /** {@inheritDoc} */
    public void startThreadProfiling() {
        ControllerImpl.startThreadProfiling();
    }

    /** {@inheritDoc} */
    public void stopThreadProfiling() {
        ControllerImpl.stopThreadProfiling();
    }

    /** {@inheritDoc} */
    public void startVMTelemetryRecording() {
        ControllerImpl.startVMTelemetryRecording();
    }

    /** {@inheritDoc} */
    public void stopVMTelemetryRecording() {
        ControllerImpl.stopVMTelemetryRecording();
    }

    /** {@inheritDoc} */
    public void saveSnapshotOnExit(String file) {
        ControllerImpl.saveSnapshotOnExit(new File(file));
    }

    /** {@inheritDoc} */
    public void enableTriggerGroup(boolean enabled, String groupId) throws IllegalArgumentException {
        ControllerImpl.enableTriggerGroup(enabled, groupId);
    }

    /** {@inheritDoc} */
    public void enableTriggers(boolean enabled) {
        ControllerImpl.enableTriggers(enabled);
    }

     /** {@inheritDoc} */
    public void startMethodStatsRecording() {
        ControllerImpl.startMethodStatsRecording();
    }

    /** {@inheritDoc} */
    public void stopMethodStatsRecording() {
        ControllerImpl.stopMethodStatsRecording();
    }

    /** {@inheritDoc} */
    public void startMonitorRecording() {
        ControllerImpl.startMonitorRecording();
    }

    /** {@inheritDoc} */
    public void startMonitorRecording(int blockedThreshold, int waitingThreshold) {
        ControllerImpl.startMonitorRecording(blockedThreshold, waitingThreshold);
    }

    /** {@inheritDoc} */
    public void stopMonitorRecording() {
        ControllerImpl.stopMonitorRecording();
    }

    /** {@inheritDoc} */
    public void triggerThreadDump() {
        ControllerImpl.triggerThreadDump();
    }

    /** {@inheritDoc} */
    public void startProbeRecording(String probeName, boolean events) {
        ControllerImpl.startProbeRecording(probeName, events);
    }

    /** {@inheritDoc} */
    public void stopProbeRecording(String probeName) {
        ControllerImpl.stopProbeRecording(probeName);
    }
}
