package com.jprofiler.api.agent.probe;

/**
 * A probe provider is queried by the profiling agent for the probes that should be activated.
 * To add your probes to the profiled JVM, you have to create an implementation that
 * instantiates all probes and returns them in an array. In addition, you have to add the VM parameter
 * <pre>
 * -Djprofiler.probeProvider=fully-qualified-class
 * </pre>
 * to the java call of the profiled process.
 * <p>
 *     Probes are only functional if the JVM is actually profiled, i.e. the <tt>-agentpath:[path to jprofilerti library]</tt>
 *     (JVMTI) or the <tt>-Xrunjprofiler</tt> (JVMPI) argument is present as a JVM parameter.
 * <p>
 * <p>
 *     Note that if you define custom probes in the JProfiler GUI, you will not have to use this class since JProfiler
 *     deploys your custom probes in that case.
 * </p>
 */
public interface ProbeProvider {

    /**
     * Returns the probes that should be activated.
     * <p>
     *     If you analyze payload information with the profiling platform, the payload id is always equal to the one-based
     *     index in the returned array, i.e. if you return a single interceptor, the payload id is always 1.
     * </p>
     * @return the interceptors
     */
    Probe[] getProbes();
}
